@@ -3,7 +3,7 @@ BEGIN {
   $App::QuoteCC::Output::Perl::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $App::QuoteCC::Output::Perl::VERSION = '0.07';
+  $App::QuoteCC::Output::Perl::VERSION = '0.08';
 }
 
 use 5.010;
@@ -12,7 +12,6 @@ use warnings;
 use Moose;
 use Data::Dump 'dump';
 use Template;
-use Encode;
 use Data::Section qw/ -setup /;
 use namespace::clean -except => [ qw/ meta merged_section_data section_data / ];
 
@@ -50,9 +49,6 @@ sub _process_template {
     my $template = $self->template;
     my $out;
 
-    # emit raw octets, not UTF-8 marked strings with clever escaping.
-    $_ = encode("utf8", $_) for @$quotes;
-
     Template->new->process(
         \$template,
         {
