@@ -3,7 +3,7 @@ BEGIN {
   $App::QuoteCC::Role::Input::AUTHORITY = 'cpan:AVAR';
 }
 BEGIN {
-  $App::QuoteCC::Role::Input::VERSION = '0.07';
+  $App::QuoteCC::Role::Input::VERSION = '0.08';
 }
 
 use 5.010;
@@ -24,11 +24,12 @@ sub file_handle {
 
     given ($file) {
         when ('-') {
-            binmode STDIN, ":encoding(UTF-8)";
+            binmode STDIN;
             return *STDIN;
         }
         default {
-            open my $fh, '<:encoding(UTF-8)', $file;
+            open my $fh, '<', $file;
+            binmode $fh;
             return $fh;
         }
     }
